import QtQuick 2.12
import QtQuick.Controls 1.5 as Qt1
import QtQuick.Controls 2.12
import QtQuick.Controls.Styles 1.4

Item {
    ScrollBar {
        id: vbar
        z: 100
        orientation: Qt.Vertical
        anchors.top: treeView.top
        anchors.right: parent.right
        anchors.rightMargin: 1
        anchors.bottom: treeView.bottom
        active: true
        visible: treeView.flickableItem.visibleArea.heightRatio  < 1.0
        contentItem: Rectangle {
            color: "transparent"
            width: 10   // This will be overridden by the width of the scrollbar
            height: 10  // This will be overridden based on the size of the scrollbar
            Rectangle {
                color: "#0c2c32"
                radius: height / 2
                width: 14
                height: parent.height
                anchors.centerIn: parent
            }
        }

        position: treeView.flickableItem.contentY / treeView.flickableItem.contentHeight;

        onPositionChanged: {
            if (pressed) {
                treeView.flickableItem.contentY =  treeView.flickableItem.contentHeight * position;
            }
        }

        background: Rectangle {
            color: "black"
            opacity: 0.5
        }

        size: (treeView.height) / (treeView.flickableItem.contentItem.height)
        minimumSize: 0.1
        width: 40
    }

    Qt1.TreeView {
        id: treeView
        anchors.fill: parent
        model: fileSystemModel
        headerVisible: false
        frameVisible: false
        horizontalScrollBarPolicy: Qt.ScrollBarAlwaysOff
        verticalScrollBarPolicy: Qt.ScrollBarAlwaysOff

        style: TreeViewStyle {
            indentation: 40
            backgroundColor: "#081c20"
        }

        rowDelegate: Rectangle {
            height: 30
            width: parent.width
            anchors.left: parent.left
            color: styleData.row % 2 == 0 ? "#0c2c32" : "#081c20"
        }

        itemDelegate: Text {
            text: styleData.value
            color: "white"
            font.pixelSize: 20
            font.family: "Noto Sans"
            font.bold: styleData.selected
        }

        Qt1.TableViewColumn {
            title: "Name"
            role: "fileName"
            resizable: true
        }

        onClicked: {
            if (treeView.isExpanded(index)) {
                treeView.collapse(index)
            } else {
                treeView.expand(index)
            }
        }

        MouseArea {
            anchors.fill: parent
            acceptedButtons: Qt.MidButton
            onWheel: {
                vbar.position = treeView.flickableItem.contentY/ treeView.flickableItem.contentHeight
                wheel.accepted = false
            }
        }
    }


    Button {
        text: "Select"
        width: 80
        height: 40
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.margins: 10
        onClicked: {
            console.log("treeView.currentIndex=", treeView.currentIndex);
            var filePath = fileSystemModel.filePath(treeView.currentIndex);
            console.log("filePath=", filePath);
        }
    }
}
